@@ -5,7 +5,7 @@ from onnxruntime import GraphOptimizationLevel, InferenceSession, SessionOptions
 from onnxruntime.quantization import QuantType, quantize_dynamic
 
 
-def generic_optimize_onnx(onnx_path: str, output_path: str) -> None:
+def generic_optimize_onnx(onnx_path: str, output_path: str, quant_type='int8') -> None:
     """Apply dynamic quantization to any onnx model.
 
     This can be used to any model, and also to second optimization step.
@@ -17,7 +17,14 @@ def generic_optimize_onnx(onnx_path: str, output_path: str) -> None:
     output_path: str
         path of optimized onnx model.
     """
-    quantize_dynamic(model_input=onnx_path, model_output=output_path, weight_type=QuantType.QInt8)
+    if 'int8' == quant_type:
+        qtype = QuantType.QInt8
+    elif 'uint8' == quant_type:
+        qtype = QuantType.QUInt8
+    else:
+        raise ValueError(f"unknow QuantType {quant_type}")
+
+    quantize_dynamic(model_input=onnx_path, model_output=output_path, weight_type=qtype)
 
 
 def create_model_for_provider(path: str, provider_to_use: str) -> InferenceSession:
